Learn R Programming

Brobdingnag (version 1.3-1)

brobmat: Brobdingnagian matrices

Description

Basic matrix arithmetic for Brobdingnagian numbers. Matrix addition, multiplication extraction and replacement implemented but not the determinant or matrix inverse.

Usage

brobmat(..., positive)
newbrobmat(x,positive)
as.brobmat(x)
is.brobmat(x)
brobmat_to_brob(x)
diag(x,...)
# S3 method for brobmat
print(x,...)
t(x,...)

Value

Generally return a brobmat or brob.

Arguments

x

Argument

...

Further arguments

positive

Logical, indicating whether an element is positive

Author

Robin K. S. Hankin

Details

Basic arithmetic for Brobdingnagian matrices.

To create a Brobdingnagian matrix, use as.brobmat(); function brobmat() can be confusing.

Function brobmat() is like brob() in that it interprets its first argument as the exponent (but creates a matrix); the sign of the entry is given by Boolean argument positive. Note that brobmat() accepts a Brobdingnagian vector as primary argument, and in this case the sign is respected.

Function as.brobmat() coerces a numeric matrix to a brobmat.

Examples

Run this code

(M <- brobmat(-10:19,5,6))
all(M > 0)  # should be TRUE (sic)

as.brobmat(matrix(-10:19,5,6))

Run the code above in your browser using DataLab