ll{
Package: Brobdingnag
Type: Package
Version: 1.0-1
Date: 2006-09-21
License: GPL
}The user should coerce numeric vectors to brobs using as.brob().
The 4 arithmetic operations, concatenation, trig functions, comparisons,
and so forth, should operate on brobs transparently.
The basic low-level function is brob(), which takes two vectors:
a double for the value and a logical for the sign (defaulting to
positive). Given x, function brob(x) returns $e^x$.
Functions as.glub() and glub() perform analogous
operations for the complex plane.