Learn R Programming

Brobdingnag (version 1.2-2)

glub-class: Class "glub"

Description

Complex Brobdingnagian numbers

Arguments

Objects from the Class

A glub object holds two slots, both brobs, representing the real and imaginary components of a complex vector.

Extends

Class "swift", directly.

See Also

brob-class,swift-class

Examples

Run this code
a <- as.brob(45)
new("glub",real=a, imag=a)

as.brob(5+5i)   # standard colloquial R idiom

Run the code above in your browser using DataLab